defenv.usage


-mainclj

(-main & _)

A very simple example of how to use the library. Just run lein usage.

A very simple example of how to use the library. Just run `lein usage`.
raw docstring

defenv-missing-no-docsclj


env-mapclj


env-map-specclj


handle-exceptioncljmacro

(handle-exception & body)

missingclj


parse-brokenclj

(parse-broken x)

parse-errorclj


secret-parse-errorclj


secret-thingclj


sensible-defaultclj


some-keywordclj


testingclj


truly-optionalclj

cljdoc builds & hosts documentation for Clojure/Script libraries