(-main & _)A very simple example of how to use the library. Just run lein usage.
A very simple example of how to use the library. Just run `lein usage`.
(handle-exception & body)(parse-broken x)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |